module CrmUc
  module Userable
    extend ActiveSupport::Concern

    included do
      include CrmUc::UserCenterable

      # 如果要判断user是不是独立版用户,请用User#ikcrm_user?方法
      enum user_type: {
        normal_user: 0,
        dingtalk_user: 1,
        kingdee_user: 2,
        wechat_user: 3,
        wx_user: 4
      }
      enum status: [:hide, :visible]

      if AppSettings.uc_enabled?
        enum permission: [:deny, :edit, :show]
      end

      default_scope { usable }

      scope :stateless, -> { unscope(where: [:status, :locked_at, :usable]) }
      scope :visible, -> { stateless.where(status: statuses[:visible]) }
      scope :usable, -> {
        if AppSettings.uc_enabled?
          where(usable: true)
        else
          where(status: statuses[:visible], locked_at: nil)
        end
      }
    end

  end
end
